"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    identity_pool_id: str,
    identity_id: str,
    dataset_name: str,
    last_sync_count: int = None,
    next_token: str = None,
    max_results: int = None,
    sync_session_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets paginated records, optionally changed after a particular sync count for a dataset and identity. With Amazon Cognito Sync, each identity has access only to its own data. Thus, the credentials used to make this API call need to have access to the identity data. ListRecords can be called with temporary user credentials provided by Cognito Identity or with developer credentials. You should use Cognito Identity credentials to make this API call.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        identity_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        dataset_name(str): A string of up to 128 characters. Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-' (dash), and '.' (dot).
        last_sync_count(int, optional): The last server sync count for this record. Defaults to None.
        next_token(str, optional): A pagination token for obtaining the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned. Defaults to None.
        sync_session_token(str, optional): A token containing a session ID, identity ID, and expiration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.record.list_all(
                ctx, identity_pool_id=value, identity_id=value, dataset_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.record.list_all identity_pool_id=value, identity_id=value, dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="list_records",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "DatasetName": dataset_name,
            "LastSyncCount": last_sync_count,
            "NextToken": next_token,
            "MaxResults": max_results,
            "SyncSessionToken": sync_session_token,
        },
    )


async def update_multiple(
    hub,
    ctx,
    identity_pool_id: str,
    identity_id: str,
    dataset_name: str,
    sync_session_token: str,
    device_id: str = None,
    record_patches: List = None,
    client_context: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Posts updates to records and adds and deletes records for a dataset and user. The sync count in the record patch is your last known sync count for that record. The server will reject an UpdateRecords request with a ResourceConflictException if you try to patch a record with a new value but a stale sync count.For example, if the sync count on the server is 5 for a key called highScore and you try and submit a new highScore with sync count of 4, the request will be rejected. To obtain the current sync count for a record, call ListRecords. On a successful update of the record, the response returns the new sync count for that record. You should present that sync count the next time you try to update that same record. When the record does not exist, specify the sync count as 0. This API can be called with temporary user credentials provided by Cognito Identity or with developer credentials.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        identity_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
        dataset_name(str): A string of up to 128 characters. Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-' (dash), and '.' (dot).
        device_id(str, optional): The unique ID generated for this device by Cognito. Defaults to None.
        record_patches(List, optional): A list of patch operations. Defaults to None.
        sync_session_token(str): The SyncSessionToken returned by a previous call to ListRecords for this dataset and identity.
        client_context(str, optional): Intended to supply a device ID that will populate the lastModifiedBy field referenced in other methods. The ClientContext field is not yet implemented. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.record.update_multiple(
                ctx,
                identity_pool_id=value,
                identity_id=value,
                dataset_name=value,
                sync_session_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.record.update_multiple identity_pool_id=value, identity_id=value, dataset_name=value, sync_session_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="update_records",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "DatasetName": dataset_name,
            "DeviceId": device_id,
            "RecordPatches": record_patches,
            "SyncSessionToken": sync_session_token,
            "ClientContext": client_context,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, arn: str, service_namespaces: List, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of policies that the IAM identity (user, group, or role) can use to access each specified service.  This operation does not use other policy types when determining whether a resource could access a service. These other policy types include resource-based policies, access control lists, Organizations policies, IAM permissions boundaries, and STS assume role policies. It only applies permissions policy logic. For more about the evaluation of policy types, see Evaluating policies in the IAM User Guide.  The list of policies returned by the operation depends on the ARN of the identity that you provide.    User – The list of policies includes the managed and inline policies that are attached to the user directly. The list also includes any additional managed and inline policies that are attached to the group to which the user belongs.     Group – The list of policies includes only the managed and inline policies that are attached to the group directly. Policies that are attached to the group’s user are not included.    Role – The list of policies includes only the managed and inline policies that are attached to the role.   For each managed policy, this operation returns the ARN and policy name. For each inline policy, it returns the policy name and the entity to which it is attached. Inline policies do not have an ARN. For more information about these policy types, see Managed policies and inline policies in the IAM User Guide. Policies that are attached to users and roles as permissions boundaries are not returned. To view which managed policy is currently used to set the permissions boundary for a user or role, use the GetUser or GetRole operations.

    Args:
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        arn(str): The ARN of the IAM identity (user, group, or role) whose policies you want to list.
        service_namespaces(List): The service namespace for the Amazon Web Services services whose policies you want to list. To learn the service namespace for a service, see Actions, resources, and condition keys for Amazon Web Services services in the IAM User Guide. Choose the name of the service to view details for that service. In the first paragraph, find the service prefix. For example, (service prefix: a4b). For more information about service namespaces, see Amazon Web Services service namespaces in the Amazon Web Services General Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.granting_service_access.list(
                ctx, arn=value, service_namespaces=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.granting_service_access.list arn=value, service_namespaces=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_policies_granting_service_access",
        op_kwargs={
            "Marker": marker,
            "Arn": arn,
            "ServiceNamespaces": service_namespaces,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, caller_reference: str, hosted_zone_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a delegation set (a group of four name servers) that can be reused by multiple hosted zones that were created by the same account.  You can also create a reusable delegation set that uses the four name servers that are associated with an existing hosted zone. Specify the hosted zone ID in the CreateReusableDelegationSet request.  You can't associate a reusable delegation set with a private hosted zone.  For information about using a reusable delegation set to configure white label name servers, see Configuring White Label Name Servers. The process for migrating existing hosted zones to use a reusable delegation set is comparable to the process for configuring white label name servers. You need to perform the following steps:   Create a reusable delegation set.   Recreate hosted zones, and reduce the TTL to 60 seconds or less.   Recreate resource record sets in the new hosted zones.   Change the registrar's name servers to use the name servers for the new hosted zones.   Monitor traffic for the website or application.   Change TTLs back to their original values.   If you want to migrate existing hosted zones to use a reusable delegation set, the existing hosted zones can't use any of the name servers that are assigned to the reusable delegation set. If one or more hosted zones do use one or more name servers that are assigned to the reusable delegation set, you can do one of the following:   For small numbers of hosted zones—up to a few hundred—it's relatively easy to create reusable delegation sets until you get one that has four name servers that don't overlap with any of the name servers in your hosted zones.   For larger numbers of hosted zones, the easiest solution is to use more than one reusable delegation set.   For larger numbers of hosted zones, you can also migrate hosted zones that have overlapping name servers to hosted zones that don't have overlapping name servers, then migrate the hosted zones again to use the reusable delegation set.

    Args:
        caller_reference(str): A unique string that identifies the request, and that allows you to retry failed CreateReusableDelegationSet requests without the risk of executing the operation twice. You must use a unique CallerReference string every time you submit a CreateReusableDelegationSet request. CallerReference can be any unique string, for example a date/time stamp.
        hosted_zone_id(str, optional): If you want to mark the delegation set for an existing hosted zone as reusable, the ID for that hosted zone. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.reusable_delegation_set_.init.create(
                ctx, caller_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.reusable_delegation_set_.init.create caller_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_reusable_delegation_set",
        op_kwargs={"CallerReference": caller_reference, "HostedZoneId": hosted_zone_id},
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a reusable delegation set.  You can delete a reusable delegation set only if it isn't associated with any hosted zones.  To verify that the reusable delegation set is not associated with any hosted zones, submit a GetReusableDelegationSet request and specify the ID of the reusable delegation set that you want to delete.

    Args:
        id_(str): The ID of the reusable delegation set that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.reusable_delegation_set_.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.reusable_delegation_set_.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="delete_reusable_delegation_set",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a specified reusable delegation set, including the four name servers that are assigned to the delegation set.

    Args:
        id_(str): The ID of the reusable delegation set that you want to get a list of name servers for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.reusable_delegation_set_.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.reusable_delegation_set_.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_reusable_delegation_set",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, marker: str = None, max_items: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of the reusable delegation sets that are associated with the current account.

    Args:
        marker(str, optional): If the value of IsTruncated in the previous response was true, you have more reusable delegation sets. To get another group, submit another ListReusableDelegationSets request.  For the value of marker, specify the value of NextMarker from the previous response, which is the ID of the first reusable delegation set that Amazon Route 53 will return if you submit another request. If the value of IsTruncated in the previous response was false, there are no more reusable delegation sets to get. Defaults to None.
        max_items(str, optional): The number of reusable delegation sets that you want Amazon Route 53 to return in the response to this request. If you specify a value greater than 100, Route 53 returns only the first 100 reusable delegation sets. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.reusable_delegation_set_.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.reusable_delegation_set_.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_reusable_delegation_sets",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub, ctx, cluster_identifier: str, aqua_configuration_status: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies whether a cluster can use AQUA (Advanced Query Accelerator).

    Args:
        cluster_identifier(str): The identifier of the cluster to be modified.
        aqua_configuration_status(str, optional): The new value of AQUA configuration status. Possible values include the following.   enabled - Use AQUA if it is available for the current Amazon Web Services Region and Amazon Redshift node type.   disabled - Don't use AQUA.    auto - Amazon Redshift determines whether to use AQUA.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.aqua_configuration.modify(
                ctx, cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.aqua_configuration.modify cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_aqua_configuration",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "AquaConfigurationStatus": aqua_configuration_status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, report_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified report.

    Args:
        report_name(str, optional): The name of the report that you want to delete. The name must be unique, is case sensitive, and can't include spaces. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cur_report_definition.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cur_report_definition.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cur",
        operation="delete_report_definition",
        op_kwargs={"ReportName": report_name},
    )


async def describe_all(
    hub, ctx, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the AWS Cost and Usage reports available to this account.

    Args:
        max_results(int, optional): The maximum number of results that AWS returns for the operation. Defaults to None.
        next_token(str, optional): A generic string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cur_report_definition.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cur_report_definition.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cur",
        operation="describe_report_definitions",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def modify(hub, ctx, report_name: str, report_definition: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Allows you to programatically update your report preferences.

    Args:
        report_name(str): The name of the report that you want to create. The name must be unique, is case sensitive, and can't include spaces. .
        report_definition(Dict): The definition of AWS Cost and Usage Report. You can specify the report name, time unit, report format, compression format, S3 bucket, additional artifacts, and schema elements in the definition. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cur_report_definition.modify(
                ctx, report_name=value, report_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cur_report_definition.modify report_name=value, report_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cur",
        operation="modify_report_definition",
        op_kwargs={"ReportName": report_name, "ReportDefinition": report_definition},
    )


async def put(hub, ctx, report_definition: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new report using the description that you provide.

    Args:
        report_definition(Dict): Represents the output of the PutReportDefinition operation. The content consists of the detailed metadata and data file information. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cur_report_definition.put(ctx, report_definition=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cur_report_definition.put report_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cur",
        operation="put_report_definition",
        op_kwargs={"ReportDefinition": report_definition},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def configure(hub, ctx, load_balancer_name: str, health_check: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Specifies the health check settings to use when evaluating the health state of your EC2 instances. For more information, see Configure Health Checks for Your Load Balancer in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        health_check(Dict): The configuration information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.health_check.configure(
                ctx, load_balancer_name=value, health_check=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.health_check.configure load_balancer_name=value, health_check=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="configure_health_check",
        op_kwargs={"LoadBalancerName": load_balancer_name, "HealthCheck": health_check},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a description of a Server Message Block (SMB) file share settings from a file gateway. This operation is only supported for file gateways.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.smb.setting.describe_all(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.smb.setting.describe_all gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_smb_settings",
        op_kwargs={"GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, workload_id: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    List lens notifications.

    Args:
        workload_id(str, optional): The ID assigned to the workload. This ID is unique within an AWS Region. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.notification.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.notification.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="list_notifications",
        op_kwargs={
            "WorkloadId": workload_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def assume(
    hub,
    ctx,
    role_arn: str,
    role_session_name: str,
    policy_arns: List = None,
    policy: str = None,
    duration_seconds: int = None,
    tags: List = None,
    transitive_tag_keys: List = None,
    external_id: str = None,
    serial_number: str = None,
    token_code: str = None,
    source_identity: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a set of temporary security credentials that you can use to access Amazon Web Services resources that you might not normally have access to. These temporary credentials consist of an access key ID, a secret access key, and a security token. Typically, you use AssumeRole within your account or for cross-account access. For a comparison of AssumeRole with other API operations that produce temporary credentials, see Requesting Temporary Security Credentials and Comparing the STS API operations in the IAM User Guide.  Permissions  The temporary security credentials created by AssumeRole can be used to make API calls to any Amazon Web Services service with the following exception: You cannot call the STS GetFederationToken or GetSessionToken API operations. (Optional) You can pass inline or managed session policies to this operation. You can pass a single JSON policy document to use as an inline session policy. You can also specify up to 10 managed policies to use as managed session policies. The plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide. To assume a role from a different account, your account must be trusted by the role. The trust relationship is defined in the role's trust policy when the role is created. That trust policy states which accounts are allowed to delegate that access to users in the account.  A user who wants to access a role in a different account must also have permissions that are delegated from the user account administrator. The administrator must attach a policy that allows the user to call AssumeRole for the ARN of the role in the other account. If the user is in the same account as the role, then you can do either of the following:   Attach a policy to the user (identical to the previous user in a different account).   Add the user as a principal directly in the role's trust policy.   In this case, the trust policy acts as an IAM resource-based policy. Users in the same account as the role do not need explicit permission to assume the role. For more information about trust policies and resource-based policies, see IAM Policies in the IAM User Guide.  Tags  (Optional) You can pass tag key-value pairs to your session. These tags are called session tags. For more information about session tags, see Passing Session Tags in STS in the IAM User Guide. An administrator must grant you the permissions necessary to pass session tags. The administrator can also create granular permissions to allow you to pass only specific session tags. For more information, see Tutorial: Using Tags for Attribute-Based Access Control in the IAM User Guide. You can set the session tags as transitive. Transitive tags persist during role chaining. For more information, see Chaining Roles with Session Tags in the IAM User Guide.  Using MFA with AssumeRole  (Optional) You can include multi-factor authentication (MFA) information when you call AssumeRole. This is useful for cross-account scenarios to ensure that the user that assumes the role has been authenticated with an Amazon Web Services MFA device. In that scenario, the trust policy of the role being assumed includes a condition that tests for MFA authentication. If the caller does not include valid MFA information, the request to assume the role is denied. The condition in a trust policy that tests for MFA authentication might look like the following example.  "Condition": {"Bool": {"aws:MultiFactorAuthPresent": true}}  For more information, see Configuring MFA-Protected API Access in the IAM User Guide guide. To use MFA with AssumeRole, you pass values for the SerialNumber and TokenCode parameters. The SerialNumber value identifies the user's hardware or virtual MFA device. The TokenCode is the time-based one-time password (TOTP) that the MFA device produces.

    Args:
        role_arn(str): The Amazon Resource Name (ARN) of the role to assume.
        role_session_name(str): An identifier for the assumed role session. Use the role session name to uniquely identify a session when the same role is assumed by different principals or for different reasons. In cross-account scenarios, the role session name is visible to, and can be logged by the account that owns the role. The role session name is also used in the ARN of the assumed role principal. This means that subsequent cross-account API requests that use the temporary security credentials will expose the role session name to the external account in their CloudTrail logs. The regex used to validate this parameter is a string of characters consisting of upper- and lower-case alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@-.
        policy_arns(List, optional): The Amazon Resource Names (ARNs) of the IAM managed policies that you want to use as managed session policies. The policies must exist in the same account as the role. This parameter is optional. You can provide up to 10 managed policy ARNs. However, the plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.   Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide. Defaults to None.
        policy(str, optional): An IAM policy in JSON format that you want to use as an inline session policy. This parameter is optional. Passing policies to this operation returns new temporary credentials. The resulting session's permissions are the intersection of the role's identity-based policy and the session policies. You can use the role's temporary credentials in subsequent Amazon Web Services API calls to access resources in the account that owns the role. You cannot use session policies to grant more permissions than those allowed by the identity-based policy of the role that is being assumed. For more information, see Session Policies in the IAM User Guide. The plaintext that you use for both inline and managed session policies can't exceed 2,048 characters. The JSON policy characters can be any ASCII character from the space character to the end of the valid character list (\u0020 through \u00FF). It can also include the tab (\u0009), linefeed (\u000A), and carriage return (\u000D) characters.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.  . Defaults to None.
        duration_seconds(int, optional): The duration, in seconds, of the role session. The value specified can can range from 900 seconds (15 minutes) up to the maximum session duration that is set for the role. The maximum session duration setting can have a value from 1 hour to 12 hours. If you specify a value higher than this setting or the administrator setting (whichever is lower), the operation fails. For example, if you specify a session duration of 12 hours, but your administrator set the maximum session duration to 6 hours, your operation fails. To learn how to view the maximum value for your role, see View the Maximum Session Duration Setting for a Role in the IAM User Guide. By default, the value is set to 3600 seconds.   The DurationSeconds parameter is separate from the duration of a console session that you might request using the returned credentials. The request to the federation endpoint for a console sign-in token takes a SessionDuration parameter that specifies the maximum length of the console session. For more information, see Creating a URL that Enables Federated Users to Access the Management Console in the IAM User Guide. . Defaults to None.
        tags(List, optional): A list of session tags that you want to pass. Each session tag consists of a key name and an associated value. For more information about session tags, see Tagging STS Sessions in the IAM User Guide. This parameter is optional. You can pass up to 50 session tags. The plaintext session tag keys can’t exceed 128 characters, and the values can’t exceed 256 characters. For these and additional limits, see IAM and STS Character Limits in the IAM User Guide.  An Amazon Web Services conversion compresses the passed session policies and session tags into a packed binary format that has a separate limit. Your request can fail for this limit even if your plaintext meets the other requirements. The PackedPolicySize response element indicates by percentage how close the policies and tags for your request are to the upper size limit.   You can pass a session tag with the same key as a tag that is already attached to the role. When you do, session tags override a role tag with the same key.  Tag key–value pairs are not case sensitive, but case is preserved. This means that you cannot have separate Department and department tag keys. Assume that the role has the Department=Marketing tag and you pass the department=engineering session tag. Department and department are not saved as separate tags, and the session tag passed in the request takes precedence over the role tag. Additionally, if you used temporary credentials to perform this operation, the new session inherits any transitive session tags from the calling session. If you pass a session tag with the same key as an inherited tag, the operation fails. To view the inherited tags for a session, see the CloudTrail logs. For more information, see Viewing Session Tags in CloudTrail in the IAM User Guide. Defaults to None.
        transitive_tag_keys(List, optional): A list of keys for session tags that you want to set as transitive. If you set a tag key as transitive, the corresponding key and value passes to subsequent sessions in a role chain. For more information, see Chaining Roles with Session Tags in the IAM User Guide. This parameter is optional. When you set session tags as transitive, the session policy and session tags packed binary limit is not affected. If you choose not to specify a transitive tag key, then no tags are passed from this session to any subsequent sessions. Defaults to None.
        external_id(str, optional): A unique identifier that might be required when you assume a role in another account. If the administrator of the account to which the role belongs provided you with an external ID, then provide that value in the ExternalId parameter. This value can be any string, such as a passphrase or account number. A cross-account role is usually set up to trust everyone in an account. Therefore, the administrator of the trusting account might send an external ID to the administrator of the trusted account. That way, only someone with the ID can assume the role, rather than everyone in the account. For more information about the external ID, see How to Use an External ID When Granting Access to Your Amazon Web Services Resources to a Third Party in the IAM User Guide. The regex used to validate this parameter is a string of characters consisting of upper- and lower-case alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@:/-. Defaults to None.
        serial_number(str, optional): The identification number of the MFA device that is associated with the user who is making the AssumeRole call. Specify this value if the trust policy of the role being assumed includes a condition that requires MFA authentication. The value is either the serial number for a hardware device (such as GAHT12345678) or an Amazon Resource Name (ARN) for a virtual device (such as arn:aws:iam::123456789012:mfa/user). The regex used to validate this parameter is a string of characters consisting of upper- and lower-case alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@-. Defaults to None.
        token_code(str, optional): The value provided by the MFA device, if the trust policy of the role being assumed requires MFA. (In other words, if the policy includes a condition that tests for MFA). If the role being assumed requires MFA and if the TokenCode value is missing or expired, the AssumeRole call returns an "access denied" error. The format for this parameter, as described by its regex pattern, is a sequence of six numeric digits. Defaults to None.
        source_identity(str, optional): The source identity specified by the principal that is calling the AssumeRole operation. You can require users to specify a source identity when they assume a role. You do this by using the sts:SourceIdentity condition key in a role trust policy. You can use source identity information in CloudTrail logs to determine who took actions with a role. You can use the aws:SourceIdentity condition key to further control access to Amazon Web Services resources based on the value of source identity. For more information about using source identity, see Monitor and control actions taken with assumed roles in the IAM User Guide. The regex used to validate this parameter is a string of characters consisting of upper- and lower-case alphanumeric characters with no spaces. You can also include underscores or any of the following characters: =,.@-. You cannot use a value that begins with the text aws:. This prefix is reserved for Amazon Web Services internal use. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sts.role.init.assume(
                ctx, role_arn=value, role_session_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sts.role.init.assume role_arn=value, role_session_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sts",
        operation="assume_role",
        op_kwargs={
            "RoleArn": role_arn,
            "RoleSessionName": role_session_name,
            "PolicyArns": policy_arns,
            "Policy": policy,
            "DurationSeconds": duration_seconds,
            "Tags": tags,
            "TransitiveTagKeys": transitive_tag_keys,
            "ExternalId": external_id,
            "SerialNumber": serial_number,
            "TokenCode": token_code,
            "SourceIdentity": source_identity,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    bucket: str,
    key: str,
    upload_id: str,
    max_parts: int = None,
    part_number_marker: int = None,
    request_payer: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the parts that have been uploaded for a specific multipart upload. This operation must include the upload ID, which you obtain by sending the initiate multipart upload request (see CreateMultipartUpload). This request returns a maximum of 1,000 uploaded parts. The default number of parts returned is 1,000 parts. You can restrict the number of parts returned by specifying the max-parts request parameter. If your multipart upload consists of more than 1,000 parts, the response returns an IsTruncated field with the value of true, and a NextPartNumberMarker element. In subsequent ListParts requests you can include the part-number-marker query string parameter and set its value to the NextPartNumberMarker field value from the previous response. For more information on multipart uploads, see Uploading Objects Using Multipart Upload. For information on permissions required to use the multipart upload API, see Multipart Upload and Permissions. The following operations are related to ListParts:    CreateMultipartUpload     UploadPart     CompleteMultipartUpload     AbortMultipartUpload     ListMultipartUploads

    Args:
        bucket(str): The name of the bucket to which the parts are being uploaded.  When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. When using this action with Amazon S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When using this action using S3 on Outposts through the AWS SDKs, you provide the Outposts bucket ARN in place of the bucket name. For more information about S3 on Outposts ARNs, see Using S3 on Outposts in the Amazon S3 User Guide.
        key(str): Object key for which the multipart upload was initiated.
        max_parts(int, optional): Sets the maximum number of parts to return. Defaults to None.
        part_number_marker(int, optional): Specifies the part after which listing should begin. Only parts with higher part numbers will be listed. Defaults to None.
        upload_id(str): Upload ID identifying the multipart upload whose parts are being listed.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.part.init.list_all(
                ctx, bucket=value, key=value, upload_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.part.init.list_all bucket=value, key=value, upload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="list_parts",
        op_kwargs={
            "Bucket": bucket,
            "Key": key,
            "MaxParts": max_parts,
            "PartNumberMarker": part_number_marker,
            "UploadId": upload_id,
            "RequestPayer": request_payer,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )


async def upload(
    hub,
    ctx,
    bucket: str,
    key: str,
    part_number: int,
    upload_id: str,
    body: bytes = None,
    content_length: int = None,
    content_md5: str = None,
    sse_customer_algorithm: str = None,
    sse_customer_key: str = None,
    sse_customer_key_md5: str = None,
    request_payer: str = None,
    expected_bucket_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads a part in a multipart upload.  In this operation, you provide part data in your request. However, you have an option to specify your existing Amazon S3 object as a data source for the part you are uploading. To upload a part from an existing object, you use the UploadPartCopy operation.   You must initiate a multipart upload (see CreateMultipartUpload) before you can upload any part. In response to your initiate request, Amazon S3 returns an upload ID, a unique identifier, that you must include in your upload part request. Part numbers can be any number from 1 to 10,000, inclusive. A part number uniquely identifies a part and also defines its position within the object being created. If you upload a new part using the same part number that was used with a previous part, the previously uploaded part is overwritten. Each part must be at least 5 MB in size, except the last part. There is no size limit on the last part of your multipart upload. To ensure that data is not corrupted when traversing the network, specify the Content-MD5 header in the upload part request. Amazon S3 checks the part data against the provided MD5 value. If they do not match, Amazon S3 returns an error.  If the upload request is signed with Signature Version 4, then AWS S3 uses the x-amz-content-sha256 header as a checksum instead of Content-MD5. For more information see Authenticating Requests: Using the Authorization Header (AWS Signature Version 4).   Note: After you initiate multipart upload and upload one or more parts, you must either complete or abort multipart upload in order to stop getting charged for storage of the uploaded parts. Only after you either complete or abort multipart upload, Amazon S3 frees up the parts storage and stops charging you for the parts storage. For more information on multipart uploads, go to Multipart Upload Overview in the Amazon S3 User Guide . For information on the permissions required to use the multipart upload API, go to Multipart Upload and Permissions in the Amazon S3 User Guide. You can optionally request server-side encryption where Amazon S3 encrypts your data as it writes it to disks in its data centers and decrypts it for you when you access it. You have the option of providing your own encryption key, or you can use the AWS managed encryption keys. If you choose to provide your own encryption key, the request headers you provide in the request must match the headers you used in the request to initiate the upload by using CreateMultipartUpload. For more information, go to Using Server-Side Encryption in the Amazon S3 User Guide. Server-side encryption is supported by the S3 Multipart Upload actions. Unless you are using a customer-provided encryption key, you don't need to specify the encryption parameters in each UploadPart request. Instead, you only need to specify the server-side encryption parameters in the initial Initiate Multipart request. For more information, see CreateMultipartUpload. If you requested server-side encryption using a customer-provided encryption key in your initiate multipart upload request, you must provide identical encryption information in each part upload using the following headers.   x-amz-server-side-encryption-customer-algorithm   x-amz-server-side-encryption-customer-key   x-amz-server-side-encryption-customer-key-MD5    Special Errors       Code: NoSuchUpload     Cause: The specified multipart upload does not exist. The upload ID might be invalid, or the multipart upload might have been aborted or completed.      HTTP Status Code: 404 Not Found      SOAP Fault Code Prefix: Client       Related Resources     CreateMultipartUpload     CompleteMultipartUpload     AbortMultipartUpload     ListParts     ListMultipartUploads

    Args:
        body(bytes, optional): Object data. Defaults to None.
        bucket(str): The name of the bucket to which the multipart upload was initiated. When using this action with an access point, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the AWS SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide. When using this action with Amazon S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the form AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When using this action using S3 on Outposts through the AWS SDKs, you provide the Outposts bucket ARN in place of the bucket name. For more information about S3 on Outposts ARNs, see Using S3 on Outposts in the Amazon S3 User Guide.
        content_length(int, optional): Size of the body in bytes. This parameter is useful when the size of the body cannot be determined automatically. Defaults to None.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the part data. This parameter is auto-populated when using the command from the CLI. This parameter is required if object lock parameters are specified. Defaults to None.
        key(str): Object key for which the multipart upload was initiated.
        part_number(int): Part number of part being uploaded. This is a positive integer between 1 and 10,000.
        upload_id(str): Upload ID identifying the multipart upload whose part is being uploaded.
        sse_customer_algorithm(str, optional): Specifies the algorithm to use to when encrypting the object (for example, AES256). Defaults to None.
        sse_customer_key(str, optional): Specifies the customer-provided encryption key for Amazon S3 to use in encrypting data. This value is used to store the object and then it is discarded; Amazon S3 does not store the encryption key. The key must be appropriate for use with the algorithm specified in the x-amz-server-side-encryption-customer-algorithm header. This must be the same encryption key specified in the initiate multipart upload request. Defaults to None.
        sse_customer_key_md5(str, optional): Specifies the 128-bit MD5 digest of the encryption key according to RFC 1321. Amazon S3 uses this header for a message integrity check to ensure that the encryption key was transmitted without error. Defaults to None.
        request_payer(str, optional): Confirms that the requester knows that they will be charged for the request. Bucket owners need not specify this parameter in their requests. For information about downloading objects from requester pays buckets, see Downloading Objects in Requestor Pays Buckets in the Amazon S3 User Guide. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.part.init.upload(
                ctx, bucket=value, key=value, part_number=value, upload_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.part.init.upload bucket=value, key=value, part_number=value, upload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="upload_part",
        op_kwargs={
            "Body": body,
            "Bucket": bucket,
            "ContentLength": content_length,
            "ContentMD5": content_md5,
            "Key": key,
            "PartNumber": part_number,
            "UploadId": upload_id,
            "SSECustomerAlgorithm": sse_customer_algorithm,
            "SSECustomerKey": sse_customer_key,
            "SSECustomerKeyMD5": sse_customer_key_md5,
            "RequestPayer": request_payer,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, lag_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes all your link aggregation groups (LAG) or the specified LAG.

    Args:
        lag_id(str, optional): The ID of the LAG. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.lags.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.lags.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_lags",
        op_kwargs={"lagId": lag_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    account_id: str,
    operation: Dict,
    report: Dict,
    client_request_token: str,
    manifest: Dict,
    priority: int,
    role_arn: str,
    confirmation_required: bool = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    You can use S3 Batch Operations to perform large-scale batch actions on Amazon S3 objects. Batch Operations can run a single action on lists of Amazon S3 objects that you specify. For more information, see S3 Batch Operations in the Amazon S3 User Guide. This action creates a S3 Batch Operations job.  Related actions include:    DescribeJob     ListJobs     UpdateJobPriority     UpdateJobStatus     JobOperation

    Args:
        account_id(str): The account ID that creates the job.
        confirmation_required(bool, optional): Indicates whether confirmation is required before Amazon S3 runs the job. Confirmation is only required for jobs created through the Amazon S3 console. Defaults to None.
        operation(Dict): The action that you want this job to perform on every object listed in the manifest. For more information about the available actions, see Operations in the Amazon S3 User Guide.
        report(Dict): Configuration parameters for the optional job-completion report.
        client_request_token(str): An idempotency token to ensure that you don't accidentally submit the same request twice. You can use any string up to the maximum length.
        manifest(Dict): Configuration parameters for the manifest.
        description(str, optional): A description for this job. You can use any string within the permitted length. Descriptions don't need to be unique and can be used for multiple jobs. Defaults to None.
        priority(int): The numerical priority for this job. Higher numbers indicate higher priority.
        role_arn(str): The Amazon Resource Name (ARN) for the Identity and Access Management (IAM) role that Batch Operations will use to run this job's action on every object in the manifest.
        tags(List, optional): A set of tags to associate with the S3 Batch Operations job. This is an optional parameter. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.job.init.create(
                ctx,
                account_id=value,
                operation=value,
                report=value,
                client_request_token=value,
                manifest=value,
                priority=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.job.init.create account_id=value, operation=value, report=value, client_request_token=value, manifest=value, priority=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="create_job",
        op_kwargs={
            "AccountId": account_id,
            "ConfirmationRequired": confirmation_required,
            "Operation": operation,
            "Report": report,
            "ClientRequestToken": client_request_token,
            "Manifest": manifest,
            "Description": description,
            "Priority": priority,
            "RoleArn": role_arn,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, account_id: str, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the configuration parameters and status for a Batch Operations job. For more information, see S3 Batch Operations in the Amazon S3 User Guide.  Related actions include:    CreateJob     ListJobs     UpdateJobPriority     UpdateJobStatus

    Args:
        account_id(str): The account ID associated with the S3 Batch Operations job.
        job_id(str): The ID for the job whose information you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.job.init.describe(ctx, account_id=value, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.job.init.describe account_id=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="describe_job",
        op_kwargs={"AccountId": account_id, "JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(
    hub,
    ctx,
    job_id: str,
    reason_code: str = None,
    comment: str = None,
    force: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a job.

    Args:
        job_id(str): The unique identifier you assigned to this job when it was created.
        reason_code(str, optional): (Optional)A reason code string that explains why the job was canceled. Defaults to None.
        comment(str, optional): An optional comment string describing why the job was canceled. Defaults to None.
        force(bool, optional): (Optional) If true job executions with status "IN_PROGRESS" and "QUEUED" are canceled, otherwise only job executions with status "QUEUED" are canceled. The default is false. Canceling a job which is "IN_PROGRESS", will cause a device which is executing the job to be unable to update the job execution status. Use caution and ensure that each device executing a job which is canceled is able to recover to a valid state. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.init.cancel(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.init.cancel job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="cancel_job",
        op_kwargs={
            "jobId": job_id,
            "reasonCode": reason_code,
            "comment": comment,
            "force": force,
        },
    )


async def create(
    hub,
    ctx,
    job_id: str,
    targets: List,
    document_source: str = None,
    document: str = None,
    description: str = None,
    presigned_url_config: Dict = None,
    target_selection: str = None,
    job_executions_rollout_config: Dict = None,
    abort_config: Dict = None,
    timeout_config: Dict = None,
    tags: List = None,
    namespace_id: str = None,
    job_template_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a job.

    Args:
        job_id(str): A job identifier which must be unique for your AWS account. We recommend using a UUID. Alpha-numeric characters, "-" and "_" are valid for use here.
        targets(List): A list of things and thing groups to which the job should be sent.
        document_source(str, optional): An S3 link to the job document. Required if you don't specify a value for document.  If the job document resides in an S3 bucket, you must use a placeholder link when specifying the document. The placeholder link is of the following form:  ${aws:iot:s3-presigned-url:https://s3.amazonaws.com/bucket/key}  where bucket is your bucket name and key is the object in the bucket to which you are linking. . Defaults to None.
        document(str, optional): The job document. Required if you don't specify a value for documentSource. Defaults to None.
        description(str, optional): A short text description of the job. Defaults to None.
        presigned_url_config(Dict, optional): Configuration information for pre-signed S3 URLs. Defaults to None.
        target_selection(str, optional): Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a thing when the thing is added to a target group, even after the job was completed by all things originally in the group. Defaults to None.
        job_executions_rollout_config(Dict, optional): Allows you to create a staged rollout of the job. Defaults to None.
        abort_config(Dict, optional): Allows you to create criteria to abort a job. Defaults to None.
        timeout_config(Dict, optional): Specifies the amount of time each device has to finish its execution of the job. The timer is started when the job execution status is set to IN_PROGRESS. If the job execution status is not set to another terminal state before the time expires, it will be automatically set to TIMED_OUT. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the job. Defaults to None.
        namespace_id(str, optional): The namespace used to indicate that a job is a customer-managed job. When you specify a value for this parameter, AWS IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.  $aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/   The namespaceId feature is in public preview. . Defaults to None.
        job_template_arn(str, optional): The ARN of the job template used to create the job. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.init.create(ctx, job_id=value, targets=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.init.create job_id=value, targets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_job",
        op_kwargs={
            "jobId": job_id,
            "targets": targets,
            "documentSource": document_source,
            "document": document,
            "description": description,
            "presignedUrlConfig": presigned_url_config,
            "targetSelection": target_selection,
            "jobExecutionsRolloutConfig": job_executions_rollout_config,
            "abortConfig": abort_config,
            "timeoutConfig": timeout_config,
            "tags": tags,
            "namespaceId": namespace_id,
            "jobTemplateArn": job_template_arn,
        },
    )


async def delete(
    hub, ctx, job_id: str, force: bool = None, namespace_id: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes a job and its related job executions. Deleting a job may take time, depending on the number of job executions created for the job and various other factors. While the job is being deleted, the status of the job will be shown as "DELETION_IN_PROGRESS". Attempting to delete or cancel a job whose status is already "DELETION_IN_PROGRESS" will result in an error. Only 10 jobs may have status "DELETION_IN_PROGRESS" at the same time, or a LimitExceededException will occur.

    Args:
        job_id(str): The ID of the job to be deleted. After a job deletion is completed, you may reuse this jobId when you create a new job. However, this is not recommended, and you must ensure that your devices are not using the jobId to refer to the deleted job.
        force(bool, optional): (Optional) When true, you can delete a job which is "IN_PROGRESS". Otherwise, you can only delete a job which is in a terminal state ("COMPLETED" or "CANCELED") or an exception will occur. The default is false.  Deleting a job which is "IN_PROGRESS", will cause a device which is executing the job to be unable to access job information or update the job execution status. Use caution and ensure that each device executing a job which is deleted is able to recover to a valid state. . Defaults to None.
        namespace_id(str, optional): The namespace used to indicate that a job is a customer-managed job. When you specify a value for this parameter, AWS IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.  $aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/   The namespaceId feature is in public preview. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.init.delete(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.init.delete job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_job",
        op_kwargs={"jobId": job_id, "force": force, "namespaceId": namespace_id},
    )


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a job.

    Args:
        job_id(str): The unique identifier you assigned to this job when it was created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.init.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.init.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iot", operation="describe_job", op_kwargs={"jobId": job_id}
    )


async def update(
    hub,
    ctx,
    job_id: str,
    description: str = None,
    presigned_url_config: Dict = None,
    job_executions_rollout_config: Dict = None,
    abort_config: Dict = None,
    timeout_config: Dict = None,
    namespace_id: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates supported fields of the specified job.

    Args:
        job_id(str): The ID of the job to be updated.
        description(str, optional): A short text description of the job. Defaults to None.
        presigned_url_config(Dict, optional): Configuration information for pre-signed S3 URLs. Defaults to None.
        job_executions_rollout_config(Dict, optional): Allows you to create a staged rollout of the job. Defaults to None.
        abort_config(Dict, optional): Allows you to create criteria to abort a job. Defaults to None.
        timeout_config(Dict, optional): Specifies the amount of time each device has to finish its execution of the job. The timer is started when the job execution status is set to IN_PROGRESS. If the job execution status is not set to another terminal state before the time expires, it will be automatically set to TIMED_OUT. . Defaults to None.
        namespace_id(str, optional): The namespace used to indicate that a job is a customer-managed job. When you specify a value for this parameter, AWS IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.  $aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/   The namespaceId feature is in public preview. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.init.update(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.init.update job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_job",
        op_kwargs={
            "jobId": job_id,
            "description": description,
            "presignedUrlConfig": presigned_url_config,
            "jobExecutionsRolloutConfig": job_executions_rollout_config,
            "abortConfig": abort_config,
            "timeoutConfig": timeout_config,
            "namespaceId": namespace_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    detector_id: str,
    rules: List,
    description: str = None,
    external_model_endpoints: List = None,
    model_versions: List = None,
    rule_execution_mode: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a detector version. The detector version starts in a DRAFT status.

    Args:
        detector_id(str): The ID of the detector under which you want to create a new version.
        description(str, optional): The description of the detector version. Defaults to None.
        external_model_endpoints(List, optional): The Amazon Sagemaker model endpoints to include in the detector version. Defaults to None.
        rules(List): The rules to include in the detector version.
        model_versions(List, optional): The model versions to include in the detector version. Defaults to None.
        rule_execution_mode(str, optional): The rule execution mode for the rules included in the detector version. You can define and edit the rule mode at the detector version level, when it is in draft status. If you specify FIRST_MATCHED, Amazon Fraud Detector evaluates rules sequentially, first to last, stopping at the first matched rule. Amazon Fraud dectector then provides the outcomes for that single rule. If you specifiy ALL_MATCHED, Amazon Fraud Detector evaluates all rules and returns the outcomes for all matched rules.  The default behavior is FIRST_MATCHED. Defaults to None.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.version.init.create(
                ctx, detector_id=value, rules=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.version.init.create detector_id=value, rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="create_detector_version",
        op_kwargs={
            "detectorId": detector_id,
            "description": description,
            "externalModelEndpoints": external_model_endpoints,
            "rules": rules,
            "modelVersions": model_versions,
            "ruleExecutionMode": rule_execution_mode,
            "tags": tags,
        },
    )


async def delete(hub, ctx, detector_id: str, detector_version_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the detector version. You cannot delete detector versions that are in ACTIVE status. When you delete a detector version, Amazon Fraud Detector permanently deletes the detector and the data is no longer stored in Amazon Fraud Detector.

    Args:
        detector_id(str): The ID of the parent detector for the detector version to delete.
        detector_version_id(str): The ID of the detector version to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.version.init.delete(
                ctx, detector_id=value, detector_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.version.init.delete detector_id=value, detector_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_detector_version",
        op_kwargs={"detectorId": detector_id, "detectorVersionId": detector_version_id},
    )


async def get(hub, ctx, detector_id: str, detector_version_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a particular detector version.

    Args:
        detector_id(str): The detector ID.
        detector_version_id(str): The detector version ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.version.init.get(
                ctx, detector_id=value, detector_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.version.init.get detector_id=value, detector_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_detector_version",
        op_kwargs={"detectorId": detector_id, "detectorVersionId": detector_version_id},
    )


async def update(
    hub,
    ctx,
    detector_id: str,
    detector_version_id: str,
    external_model_endpoints: List,
    rules: List,
    description: str = None,
    model_versions: List = None,
    rule_execution_mode: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a detector version. The detector version attributes that you can update include models, external model endpoints, rules, rule execution mode, and description. You can only update a DRAFT detector version.

    Args:
        detector_id(str): The parent detector ID for the detector version you want to update.
        detector_version_id(str): The detector version ID. .
        external_model_endpoints(List): The Amazon SageMaker model endpoints to include in the detector version.
        rules(List): The rules to include in the detector version.
        description(str, optional): The detector version description. . Defaults to None.
        model_versions(List, optional): The model versions to include in the detector version. Defaults to None.
        rule_execution_mode(str, optional): The rule execution mode to add to the detector. If you specify FIRST_MATCHED, Amazon Fraud Detector evaluates rules sequentially, first to last, stopping at the first matched rule. Amazon Fraud dectector then provides the outcomes for that single rule. If you specifiy ALL_MATCHED, Amazon Fraud Detector evaluates all rules and returns the outcomes for all matched rules. You can define and edit the rule mode at the detector version level, when it is in draft status. The default behavior is FIRST_MATCHED. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.version.init.update(
                ctx,
                detector_id=value,
                detector_version_id=value,
                external_model_endpoints=value,
                rules=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.version.init.update detector_id=value, detector_version_id=value, external_model_endpoints=value, rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="update_detector_version",
        op_kwargs={
            "detectorId": detector_id,
            "detectorVersionId": detector_version_id,
            "externalModelEndpoints": external_model_endpoints,
            "rules": rules,
            "description": description,
            "modelVersions": model_versions,
            "ruleExecutionMode": rule_execution_mode,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def grant(hub, ctx, instance_id: str, valid_for_in_minutes: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This action can be used only with Windows stacks.  Grants RDP access to a Windows instance for a specified time period.

    Args:
        instance_id(str): The instance's AWS OpsWorks Stacks ID.
        valid_for_in_minutes(int, optional): The length of time (in minutes) that the grant is valid. When the grant expires at the end of this period, the user will no longer be able to use the credentials to log in. If the user is logged in at the time, he or she automatically will be logged out. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.access.grant(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.access.grant instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="grant_access",
        op_kwargs={
            "InstanceId": instance_id,
            "ValidForInMinutes": valid_for_in_minutes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    type_: str,
    description: str = None,
    parameters: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates (registers) a data catalog with the specified name and properties. Catalogs created are visible to all users of the same AWS account.

    Args:
        name(str): The name of the data catalog to create. The catalog name must be unique for the AWS account and can use a maximum of 128 alphanumeric, underscore, at sign, or hyphen characters.
        type_(str): The type of data catalog to create: LAMBDA for a federated catalog or HIVE for an external hive metastore.  Do not use the GLUE type. This refers to the AwsDataCatalog that already exists in your account, of which you can have only one. Specifying the GLUE type will result in an INVALID_INPUT error. .
        description(str, optional): A description of the data catalog to be created. Defaults to None.
        parameters(Dict, optional): Specifies the Lambda function or functions to use for creating the data catalog. This is a mapping whose values depend on the catalog type.    For the HIVE data catalog type, use the following syntax. The metadata-function parameter is required. The sdk-version parameter is optional and defaults to the currently supported version.  metadata-function=lambda_arn, sdk-version=version_number     For the LAMBDA data catalog type, use one of the following sets of required parameters, but not both.   If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.  metadata-function=lambda_arn, record-function=lambda_arn      If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.  function=lambda_arn      . Defaults to None.
        tags(List, optional): A list of comma separated tags to add to the data catalog that is created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.data.catalog.create(ctx, name=value, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.data.catalog.create name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="create_data_catalog",
        op_kwargs={
            "Name": name,
            "Type": type_,
            "Description": description,
            "Parameters": parameters,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a data catalog.

    Args:
        name(str): The name of the data catalog to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.data.catalog.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.data.catalog.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="delete_data_catalog",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the specified data catalog.

    Args:
        name(str): The name of the data catalog to return.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.data.catalog.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.data.catalog.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="get_data_catalog",
        op_kwargs={"Name": name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the data catalogs in the current AWS account.

    Args:
        next_token(str, optional): A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call. Defaults to None.
        max_results(int, optional): Specifies the maximum number of data catalogs to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.data.catalog.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.data.catalog.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="list_data_catalogs",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub, ctx, name: str, type_: str, description: str = None, parameters: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the data catalog that has the specified name.

    Args:
        name(str): The name of the data catalog to update. The catalog name must be unique for the AWS account and can use a maximum of 128 alphanumeric, underscore, at sign, or hyphen characters.
        type_(str): Specifies the type of data catalog to update. Specify LAMBDA for a federated catalog or HIVE for an external hive metastore.  Do not use the GLUE type. This refers to the AwsDataCatalog that already exists in your account, of which you can have only one. Specifying the GLUE type will result in an INVALID_INPUT error. .
        description(str, optional): New or modified text that describes the data catalog. Defaults to None.
        parameters(Dict, optional): Specifies the Lambda function or functions to use for updating the data catalog. This is a mapping whose values depend on the catalog type.    For the HIVE data catalog type, use the following syntax. The metadata-function parameter is required. The sdk-version parameter is optional and defaults to the currently supported version.  metadata-function=lambda_arn, sdk-version=version_number     For the LAMBDA data catalog type, use one of the following sets of required parameters, but not both.   If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.  metadata-function=lambda_arn, record-function=lambda_arn      If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.  function=lambda_arn      . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.data.catalog.update(ctx, name=value, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.data.catalog.update name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="update_data_catalog",
        op_kwargs={
            "Name": name,
            "Type": type_,
            "Description": description,
            "Parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    replication_task_arn: str = None,
    replication_instance_arn: str = None,
    source_engine_name: str = None,
    target_engine_name: str = None,
    migration_type: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of individual assessments that you can specify for a new premigration assessment run, given one or more parameters. If you specify an existing migration task, this operation provides the default individual assessments you can specify for that task. Otherwise, the specified parameters model elements of a possible migration task on which to base a premigration assessment run. To use these migration task modeling parameters, you must specify an existing replication instance, a source database engine, a target database engine, and a migration type. This combination of parameters potentially limits the default individual assessments available for an assessment run created for a corresponding migration task. If you specify no parameters, this operation provides a list of all possible individual assessments that you can specify for an assessment run. If you specify any one of the task modeling parameters, you must specify all of them or the operation cannot provide a list of individual assessments. The only parameter that you can specify alone is for an existing migration task. The specified task definition then determines the default list of individual assessments that you can specify in an assessment run for the task.

    Args:
        replication_task_arn(str, optional): Amazon Resource Name (ARN) of a migration task on which you want to base the default list of individual assessments. Defaults to None.
        replication_instance_arn(str, optional): ARN of a replication instance on which you want to base the default list of individual assessments. Defaults to None.
        source_engine_name(str, optional): Name of a database engine that the specified replication instance supports as a source. Defaults to None.
        target_engine_name(str, optional): Name of a database engine that the specified replication instance supports as a target. Defaults to None.
        migration_type(str, optional): Name of the migration type that each provided individual assessment must support. Defaults to None.
        max_records(int, optional): Maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Defaults to None.
        marker(str, optional): Optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.applicable_individual_assessment.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.applicable_individual_assessment.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_applicable_individual_assessments",
        op_kwargs={
            "ReplicationTaskArn": replication_task_arn,
            "ReplicationInstanceArn": replication_instance_arn,
            "SourceEngineName": source_engine_name,
            "TargetEngineName": target_engine_name,
            "MigrationType": migration_type,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    workteam_name: str,
    member_definitions: List,
    description: str,
    workforce_name: str = None,
    notification_configuration: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new work team for labeling your data. A work team is defined by one or more Amazon Cognito user pools. You must first create the user pools before you can create a work team. You cannot create more than 25 work teams in an account and region.

    Args:
        workteam_name(str): The name of the work team. Use this name to identify the work team.
        workforce_name(str, optional): The name of the workforce. Defaults to None.
        member_definitions(List): A list of MemberDefinition objects that contains objects that identify the workers that make up the work team.  Workforces can be created using Amazon Cognito or your own OIDC Identity Provider (IdP). For private workforces created using Amazon Cognito use CognitoMemberDefinition. For workforces created using your own OIDC identity provider (IdP) use OidcMemberDefinition. Do not provide input for both of these parameters in a single request. For workforces created using Amazon Cognito, private work teams correspond to Amazon Cognito user groups within the user pool used to create a workforce. All of the CognitoMemberDefinition objects that make up the member definition must have the same ClientId and UserPool values. To add a Amazon Cognito user group to an existing worker pool, see Adding groups to a User Pool. For more information about user pools, see Amazon Cognito User Pools. For workforces created using your own OIDC IdP, specify the user groups that you want to include in your private work team in OidcMemberDefinition by listing those groups in Groups.
        description(str): A description of the work team.
        notification_configuration(Dict, optional): Configures notification of workers regarding available or expiring work items. Defaults to None.
        tags(List, optional): An array of key-value pairs. For more information, see Resource Tag and Using Cost Allocation Tags in the  Amazon Web Services Billing and Cost Management User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workteam.create(
                ctx, workteam_name=value, member_definitions=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workteam.create workteam_name=value, member_definitions=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_workteam",
        op_kwargs={
            "WorkteamName": workteam_name,
            "WorkforceName": workforce_name,
            "MemberDefinitions": member_definitions,
            "Description": description,
            "NotificationConfiguration": notification_configuration,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, workteam_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing work team. This operation can't be undone.

    Args:
        workteam_name(str): The name of the work team to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workteam.delete(ctx, workteam_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workteam.delete workteam_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_workteam",
        op_kwargs={"WorkteamName": workteam_name},
    )


async def describe(hub, ctx, workteam_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specific work team. You can see information such as the create date, the last updated date, membership information, and the work team's Amazon Resource Name (ARN).

    Args:
        workteam_name(str): The name of the work team to return a description of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workteam.describe(ctx, workteam_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workteam.describe workteam_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_workteam",
        op_kwargs={"WorkteamName": workteam_name},
    )


async def list_all(
    hub,
    ctx,
    sort_by: str = None,
    sort_order: str = None,
    name_contains: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of private work teams that you have defined in a region. The list may be empty if no work team satisfies the filter specified in the NameContains parameter.

    Args:
        sort_by(str, optional): The field to sort results by. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.
        name_contains(str, optional): A string in the work team's name. This filter returns only work teams whose name contains the specified string. Defaults to None.
        next_token(str, optional): If the result of the previous ListWorkteams request was truncated, the response includes a NextToken. To retrieve the next set of labeling jobs, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of work teams to return in each page of the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workteam.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workteam.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_workteams",
        op_kwargs={
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NameContains": name_contains,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    workteam_name: str,
    member_definitions: List = None,
    description: str = None,
    notification_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing work team with new member definitions or description.

    Args:
        workteam_name(str): The name of the work team to update.
        member_definitions(List, optional): A list of MemberDefinition objects that contains objects that identify the workers that make up the work team.  Workforces can be created using Amazon Cognito or your own OIDC Identity Provider (IdP). For private workforces created using Amazon Cognito use CognitoMemberDefinition. For workforces created using your own OIDC identity provider (IdP) use OidcMemberDefinition. You should not provide input for both of these parameters in a single request. For workforces created using Amazon Cognito, private work teams correspond to Amazon Cognito user groups within the user pool used to create a workforce. All of the CognitoMemberDefinition objects that make up the member definition must have the same ClientId and UserPool values. To add a Amazon Cognito user group to an existing worker pool, see Adding groups to a User Pool. For more information about user pools, see Amazon Cognito User Pools. For workforces created using your own OIDC IdP, specify the user groups that you want to include in your private work team in OidcMemberDefinition by listing those groups in Groups. Be aware that user groups that are already in the work team must also be listed in Groups when you make this request to remain on the work team. If you do not include these user groups, they will no longer be associated with the work team you update. . Defaults to None.
        description(str, optional): An updated description for the work team. Defaults to None.
        notification_configuration(Dict, optional): Configures SNS topic notifications for available or expiring work items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workteam.update(ctx, workteam_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workteam.update workteam_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_workteam",
        op_kwargs={
            "WorkteamName": workteam_name,
            "MemberDefinitions": member_definitions,
            "Description": description,
            "NotificationConfiguration": notification_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    resource_group_name: str = None,
    start_time: str = None,
    end_time: str = None,
    event_status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Lists the INFO, WARN, and ERROR events for periodic configuration updates performed by Application Insights. Examples of events represented are:    INFO: creating a new alarm or updating an alarm threshold.   WARN: alarm not created due to insufficient data points used to predict thresholds.   ERROR: alarm not created due to permission errors or exceeding quotas.

    Args:
        resource_group_name(str, optional): Resource group to which the application belongs. . Defaults to None.
        start_time(str, optional): The start time of the event. . Defaults to None.
        end_time(str, optional): The end time of the event. Defaults to None.
        event_status(str, optional): The status of the configuration update event. Possible values include INFO, WARN, and ERROR. Defaults to None.
        max_results(int, optional):  The maximum number of results returned by ListConfigurationHistory in paginated output. When this parameter is used, ListConfigurationHistory returns only MaxResults in a single page along with a NextToken response element. The remaining results of the initial request can be seen by sending another ListConfigurationHistory request with the returned NextToken value. If this parameter is not used, then ListConfigurationHistory returns all results. . Defaults to None.
        next_token(str, optional): The NextToken value returned from a previous paginated ListConfigurationHistory request where MaxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the NextToken value. This value is null when there are no more results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.configuration_history.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.configuration_history.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="list_configuration_history",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "StartTime": start_time,
            "EndTime": end_time,
            "EventStatus": event_status,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, backup_job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns backup job details for the specified BackupJobId.

    Args:
        backup_job_id(str): Uniquely identifies a request to AWS Backup to back up a resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.job.describe(ctx, backup_job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.job.describe backup_job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="describe_backup_job",
        op_kwargs={"BackupJobId": backup_job_id},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    by_resource_arn: str = None,
    by_state: str = None,
    by_backup_vault_name: str = None,
    by_created_before: str = None,
    by_created_after: str = None,
    by_resource_type: str = None,
    by_account_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing backup jobs for an authenticated account for the last 30 days. For a longer period of time, consider using these monitoring tools.

    Args:
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.
        by_resource_arn(str, optional): Returns only backup jobs that match the specified resource Amazon Resource Name (ARN). Defaults to None.
        by_state(str, optional): Returns only backup jobs that are in the specified state. Defaults to None.
        by_backup_vault_name(str, optional): Returns only backup jobs that will be stored in the specified backup vault. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens. Defaults to None.
        by_created_before(str, optional): Returns only backup jobs that were created before the specified date. Defaults to None.
        by_created_after(str, optional): Returns only backup jobs that were created after the specified date. Defaults to None.
        by_resource_type(str, optional): Returns only backup jobs for the specified resources:    DynamoDB for Amazon DynamoDB    EBS for Amazon Elastic Block Store    EC2 for Amazon Elastic Compute Cloud    EFS for Amazon Elastic File System    RDS for Amazon Relational Database Service    Aurora for Amazon Aurora    Storage Gateway for AWS Storage Gateway  . Defaults to None.
        by_account_id(str, optional): The account ID to list the jobs from. Returns only backup jobs associated with the specified account ID. If used from an AWS Organizations management account, passing * returns all jobs across the organization. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_backup_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "ByResourceArn": by_resource_arn,
            "ByState": by_state,
            "ByBackupVaultName": by_backup_vault_name,
            "ByCreatedBefore": by_created_before,
            "ByCreatedAfter": by_created_after,
            "ByResourceType": by_resource_type,
            "ByAccountId": by_account_id,
        },
    )


async def start(
    hub,
    ctx,
    backup_vault_name: str,
    resource_arn: str,
    iam_role_arn: str,
    idempotency_token: str = None,
    start_window_minutes: int = None,
    complete_window_minutes: int = None,
    lifecycle: Dict = None,
    recovery_point_tags: Dict = None,
    backup_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an on-demand backup job for the specified resource.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
        resource_arn(str): An Amazon Resource Name (ARN) that uniquely identifies a resource. The format of the ARN depends on the resource type.
        iam_role_arn(str): Specifies the IAM role ARN used to create the target recovery point; for example, arn:aws:iam::123456789012:role/S3Access.
        idempotency_token(str, optional): A customer chosen string that can be used to distinguish between calls to StartBackupJob. Defaults to None.
        start_window_minutes(int, optional): A value in minutes after a backup is scheduled before a job will be canceled if it doesn't start successfully. This value is optional, and the default is 8 hours. Defaults to None.
        complete_window_minutes(int, optional): A value in minutes during which a successfully started backup must complete, or else AWS Backup will cancel the job. This value is optional. This value begins counting down from when the backup was scheduled. It does not add additional time for StartWindowMinutes, or if the backup started later than scheduled. Defaults to None.
        lifecycle(Dict, optional): The lifecycle defines when a protected resource is transitioned to cold storage and when it expires. AWS Backup will transition and expire backups automatically according to the lifecycle that you define.  Backups transitioned to cold storage must be stored in cold storage for a minimum of 90 days. Therefore, the “expire after days” setting must be 90 days greater than the “transition to cold after days” setting. The “transition to cold after days” setting cannot be changed after a backup has been transitioned to cold.  Only Amazon EFS file system backups can be transitioned to cold storage. Defaults to None.
        recovery_point_tags(Dict, optional): To help organize your resources, you can assign your own metadata to the resources that you create. Each tag is a key-value pair. Defaults to None.
        backup_options(Dict, optional): Specifies the backup option for a selected resource. This option is only available for Windows VSS backup jobs. Valid values: Set to "WindowsVSS”:“enabled" to enable WindowsVSS backup option and create a VSS Windows backup. Set to “WindowsVSS”:”disabled” to create a regular backup. The WindowsVSS option is not enabled by default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.job.start(
                ctx, backup_vault_name=value, resource_arn=value, iam_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.job.start backup_vault_name=value, resource_arn=value, iam_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="start_backup_job",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "ResourceArn": resource_arn,
            "IamRoleArn": iam_role_arn,
            "IdempotencyToken": idempotency_token,
            "StartWindowMinutes": start_window_minutes,
            "CompleteWindowMinutes": complete_window_minutes,
            "Lifecycle": lifecycle,
            "RecoveryPointTags": recovery_point_tags,
            "BackupOptions": backup_options,
        },
    )


async def stop(hub, ctx, backup_job_id: str) -> None:
    r"""
    **Autogenerated function**

    Attempts to cancel a job to create a one-time backup of a resource.

    Args:
        backup_job_id(str): Uniquely identifies a request to AWS Backup to back up a resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.job.stop(ctx, backup_job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.job.stop backup_job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="stop_backup_job",
        op_kwargs={"BackupJobId": backup_job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, description: str = None, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new, empty global network.

    Args:
        description(str, optional): A description of the global network. Length Constraints: Maximum length of 256 characters. Defaults to None.
        tags(List, optional): The tags to apply to the resource during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.global_network.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.global_network.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="create_global_network",
        op_kwargs={"Description": description, "Tags": tags},
    )


async def delete(hub, ctx, global_network_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing global network. You must first delete all global network objects (devices, links, and sites) and deregister all transit gateways.

    Args:
        global_network_id(str): The ID of the global network.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.global_network.delete(
                ctx, global_network_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.global_network.delete global_network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="delete_global_network",
        op_kwargs={"GlobalNetworkId": global_network_id},
    )


async def describe_all(
    hub,
    ctx,
    global_network_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more global networks. By default, all global networks are described. To describe the objects in your global network, you must use the appropriate Get* action. For example, to list the transit gateways in your global network, use GetTransitGatewayRegistrations.

    Args:
        global_network_ids(List, optional): The IDs of one or more global networks. The maximum is 10. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.global_network.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.global_network.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="describe_global_networks",
        op_kwargs={
            "GlobalNetworkIds": global_network_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(hub, ctx, global_network_id: str, description: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing global network. To remove information for any of the parameters, specify an empty string.

    Args:
        global_network_id(str): The ID of your global network.
        description(str, optional): A description of the global network. Length Constraints: Maximum length of 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.global_network.update(
                ctx, global_network_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.global_network.update global_network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="update_global_network",
        op_kwargs={"GlobalNetworkId": global_network_id, "Description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, service_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Initiates the verification process to prove that the service provider owns the private DNS name domain for the endpoint service. The service provider must successfully perform the verification before the consumer can use the name to access the service. Before the service provider runs this command, they must add a record to the DNS server. For more information, see Adding a TXT Record to Your Domain's DNS Server  in the Amazon VPC User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_id(str): The ID of the endpoint service.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.service.private_dns_verification.start(
                ctx, service_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.service.private_dns_verification.start service_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="start_vpc_endpoint_service_private_dns_verification",
        op_kwargs={"DryRun": dry_run, "ServiceId": service_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def search(
    hub,
    ctx,
    area_code: str = None,
    city: str = None,
    country: str = None,
    state: str = None,
    toll_free_prefix: str = None,
    phone_number_type: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for phone numbers that can be ordered. For US numbers, provide at least one of the following search filters: AreaCode, City, State, or TollFreePrefix. If you provide City, you must also provide State. Numbers outside the US only support the PhoneNumberType filter, which you must use.

    Args:
        area_code(str, optional): The area code used to filter results. Only applies to the US. Defaults to None.
        city(str, optional): The city used to filter results. Only applies to the US. Defaults to None.
        country(str, optional): The country used to filter results. Defaults to the US Format: ISO 3166-1 alpha-2. Defaults to None.
        state(str, optional): The state used to filter results. Required only if you provide City. Only applies to the US. Defaults to None.
        toll_free_prefix(str, optional): The toll-free prefix that you use to filter results. Only applies to the US. Defaults to None.
        phone_number_type(str, optional): The phone number type used to filter results. Required for non-US numbers. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): The token used to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.available_phone_number.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.available_phone_number.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="search_available_phone_numbers",
        op_kwargs={
            "AreaCode": area_code,
            "City": city,
            "Country": country,
            "State": state,
            "TollFreePrefix": toll_free_prefix,
            "PhoneNumberType": phone_number_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, medical_transcription_job_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a transcription job generated by Amazon Transcribe Medical and any related information.

    Args:
        medical_transcription_job_name(str): The name you provide to the DeleteMedicalTranscriptionJob object to delete a transcription job.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.transcription_job.delete(
                ctx, medical_transcription_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.transcription_job.delete medical_transcription_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="delete_medical_transcription_job",
        op_kwargs={"MedicalTranscriptionJobName": medical_transcription_job_name},
    )


async def get(hub, ctx, medical_transcription_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a transcription job from Amazon Transcribe Medical. To see the status of the job, check the TranscriptionJobStatus field. If the status is COMPLETED, the job is finished. You find the results of the completed job in the TranscriptFileUri field.

    Args:
        medical_transcription_job_name(str): The name of the medical transcription job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.transcription_job.get(
                ctx, medical_transcription_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.transcription_job.get medical_transcription_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="get_medical_transcription_job",
        op_kwargs={"MedicalTranscriptionJobName": medical_transcription_job_name},
    )


async def list_all(
    hub,
    ctx,
    status: str = None,
    job_name_contains: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists medical transcription jobs with a specified status or substring that matches their names.

    Args:
        status(str, optional): When specified, returns only medical transcription jobs with the specified status. Jobs are ordered by creation date, with the newest jobs returned first. If you don't specify a status, Amazon Transcribe Medical returns all transcription jobs ordered by creation date. Defaults to None.
        job_name_contains(str, optional): When specified, the jobs returned in the list are limited to jobs whose name contains the specified string. Defaults to None.
        next_token(str, optional): If you a receive a truncated result in the previous request of ListMedicalTranscriptionJobs, include NextToken to fetch the next set of jobs. Defaults to None.
        max_results(int, optional): The maximum number of medical transcription jobs to return in the response. IF there are fewer results in the list, this response contains only the actual results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.transcription_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.transcription_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="list_medical_transcription_jobs",
        op_kwargs={
            "Status": status,
            "JobNameContains": job_name_contains,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    medical_transcription_job_name: str,
    language_code: str,
    media: Dict,
    output_bucket_name: str,
    specialty: str,
    type_: str,
    media_sample_rate_hertz: int = None,
    media_format: str = None,
    output_key: str = None,
    output_encryption_kms_key_id: str = None,
    settings: Dict = None,
    content_identification_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a batch job to transcribe medical speech to text.

    Args:
        medical_transcription_job_name(str): The name of the medical transcription job. You can't use the strings "." or ".." by themselves as the job name. The name must also be unique within an AWS account. If you try to create a medical transcription job with the same name as a previous medical transcription job, you get a ConflictException error.
        language_code(str): The language code for the language spoken in the input media file. US English (en-US) is the valid value for medical transcription jobs. Any other value you enter for language code results in a BadRequestException error.
        media_sample_rate_hertz(int, optional): The sample rate, in Hertz, of the audio track in the input media file. If you do not specify the media sample rate, Amazon Transcribe Medical determines the sample rate. If you specify the sample rate, it must match the rate detected by Amazon Transcribe Medical. In most cases, you should leave the MediaSampleRateHertz field blank and let Amazon Transcribe Medical determine the sample rate. Defaults to None.
        media_format(str, optional): The audio format of the input media file. Defaults to None.
        media(Dict): Describes the input media file in a transcription request.
        output_bucket_name(str): The Amazon S3 location where the transcription is stored. You must set OutputBucketName for Amazon Transcribe Medical to store the transcription results. Your transcript appears in the S3 location you specify. When you call the GetMedicalTranscriptionJob, the operation returns this location in the TranscriptFileUri field. The S3 bucket must have permissions that allow Amazon Transcribe Medical to put files in the bucket. For more information, see Permissions Required for IAM User Roles. You can specify an AWS Key Management Service (KMS) key to encrypt the output of your transcription using the OutputEncryptionKMSKeyId parameter. If you don't specify a KMS key, Amazon Transcribe Medical uses the default Amazon S3 key for server-side encryption of transcripts that are placed in your S3 bucket.
        output_key(str, optional): You can specify a location in an Amazon S3 bucket to store the output of your medical transcription job. If you don't specify an output key, Amazon Transcribe Medical stores the output of your transcription job in the Amazon S3 bucket you specified. By default, the object key is "your-transcription-job-name.json". You can use output keys to specify the Amazon S3 prefix and file name of the transcription output. For example, specifying the Amazon S3 prefix, "folder1/folder2/", as an output key would lead to the output being stored as "folder1/folder2/your-transcription-job-name.json". If you specify "my-other-job-name.json" as the output key, the object key is changed to "my-other-job-name.json". You can use an output key to change both the prefix and the file name, for example "folder/my-other-job-name.json". If you specify an output key, you must also specify an S3 bucket in the OutputBucketName parameter. Defaults to None.
        output_encryption_kms_key_id(str, optional): The Amazon Resource Name (ARN) of the AWS Key Management Service (KMS) key used to encrypt the output of the transcription job. The user calling the StartMedicalTranscriptionJob operation must have permission to use the specified KMS key. You use either of the following to identify a KMS key in the current account:   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"   KMS Key Alias: "alias/ExampleAlias"   You can use either of the following to identify a KMS key in the current account or another account:   Amazon Resource Name (ARN) of a KMS key in the current account or another account: "arn:aws:kms:region:account ID:key/1234abcd-12ab-34cd-56ef-1234567890ab"   ARN of a KMS Key Alias: "arn:aws:kms:region:account ID:alias/ExampleAlias"   If you don't specify an encryption key, the output of the medical transcription job is encrypted with the default Amazon S3 key (SSE-S3). If you specify a KMS key to encrypt your output, you must also specify an output location in the OutputBucketName parameter. Defaults to None.
        settings(Dict, optional): Optional settings for the medical transcription job. Defaults to None.
        content_identification_type(str, optional): You can configure Amazon Transcribe Medical to label content in the transcription output. If you specify PHI, Amazon Transcribe Medical labels the personal health information (PHI) that it identifies in the transcription output. Defaults to None.
        specialty(str): The medical specialty of any clinician speaking in the input media.
        type_(str): The type of speech in the input audio. CONVERSATION refers to conversations between two or more speakers, e.g., a conversations between doctors and patients. DICTATION refers to single-speaker dictated speech, e.g., for clinical notes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.medical.transcription_job.start(
                ctx,
                medical_transcription_job_name=value,
                language_code=value,
                media=value,
                output_bucket_name=value,
                specialty=value,
                type_=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.medical.transcription_job.start medical_transcription_job_name=value, language_code=value, media=value, output_bucket_name=value, specialty=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="start_medical_transcription_job",
        op_kwargs={
            "MedicalTranscriptionJobName": medical_transcription_job_name,
            "LanguageCode": language_code,
            "MediaSampleRateHertz": media_sample_rate_hertz,
            "MediaFormat": media_format,
            "Media": media,
            "OutputBucketName": output_bucket_name,
            "OutputKey": output_key,
            "OutputEncryptionKMSKeyId": output_encryption_kms_key_id,
            "Settings": settings,
            "ContentIdentificationType": content_identification_type,
            "Specialty": specialty,
            "Type": type_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, publisher_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a CloudFormation extension publisher. If you do not supply a PublisherId, and you have registered as an extension publisher, DescribePublisher returns information about your own publisher account.  For more information on registering as a publisher, see:    RegisterPublisher     Publishing extensions to make them available for public use in the CloudFormation CLI User Guide

    Args:
        publisher_id(str, optional): The ID of the extension publisher. If you do not supply a PublisherId, and you have registered as an extension publisher, DescribePublisher returns information about your own publisher account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.publisher.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.publisher.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="describe_publisher",
        op_kwargs={"PublisherId": publisher_id},
    )


async def register(
    hub, ctx, accept_terms_and_conditions: bool = None, connection_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Registers your account as a publisher of public extensions in the CloudFormation registry. Public extensions are available for use by all CloudFormation users. This publisher ID applies to your account in all Regions. For information on requirements for registering as a public extension publisher, see Registering your account to publish CloudFormation extensions in the CloudFormation CLI User Guide.

    Args:
        accept_terms_and_conditions(bool, optional): Whether you accept the Terms and Conditions for publishing extensions in the CloudFormation registry. You must accept the terms and conditions in order to register to publish public extensions to the CloudFormation registry. The default is false. Defaults to None.
        connection_arn(str, optional): If you are using a Bitbucket or GitHub account for identity verification, the Amazon Resource Name (ARN) for your connection to that account. For more information, see Registering your account to publish CloudFormation extensions in the CloudFormation CLI User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.publisher.register(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.publisher.register
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="register_publisher",
        op_kwargs={
            "AcceptTermsAndConditions": accept_terms_and_conditions,
            "ConnectionArn": connection_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, fleet_id: str, location: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves current usage data for a fleet location. Utilization data provides a snapshot of current game hosting activity at the requested location. Use this operation to retrieve utilization information for a fleet's remote location or home Region (you can also retrieve home Region utilization by calling DescribeFleetUtilization). To retrieve utilization data, identify a fleet and location.  If successful, a FleetUtilization object is returned for the requested fleet location.   Learn more   Setting up GameLift fleets   GameLift metrics for fleets   Related actions   CreateFleetLocations | DescribeFleetLocationAttributes | DescribeFleetLocationCapacity | DescribeFleetLocationUtilization | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetUtilization | UpdateFleetCapacity | StopFleetActions | DeleteFleetLocations | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to request location utilization for. You can use either the fleet ID or ARN value.
        location(str): The fleet location to retrieve utilization information for. Specify a location in the form of an AWS Region code, such as us-west-2.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.location.utilization.describe(
                ctx, fleet_id=value, location=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.location.utilization.describe fleet_id=value, location=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_fleet_location_utilization",
        op_kwargs={"FleetId": fleet_id, "Location": location},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(hub, ctx, alarm_names: List) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified alarms. You can delete up to 100 alarms in one operation. However, this total can include no more than one composite alarm. For example, you could delete 99 metric alarms and one composite alarms with one operation, but you can't delete two composite alarms with one operation.  In the event of an error, no alarms are deleted.  It is possible to create a loop or cycle of composite alarms, where composite alarm A depends on composite alarm B, and composite alarm B also depends on composite alarm A. In this scenario, you can't delete any composite alarm that is part of the cycle because there is always still a composite alarm that depends on that alarm that you want to delete. To get out of such a situation, you must break the cycle by changing the rule of one of the composite alarms in the cycle to remove a dependency that creates the cycle. The simplest change to make to break a cycle is to change the AlarmRule of one of the alarms to False.  Additionally, the evaluation of composite alarms stops if CloudWatch detects a cycle in the evaluation path.

    Args:
        alarm_names(List): The alarms to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.alarm.init.delete_multiple(ctx, alarm_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.alarm.init.delete_multiple alarm_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="delete_alarms",
        op_kwargs={"AlarmNames": alarm_names},
    )


async def describe_all(
    hub,
    ctx,
    alarm_names: List = None,
    alarm_name_prefix: str = None,
    alarm_types: List = None,
    children_of_alarm_name: str = None,
    parents_of_alarm_name: str = None,
    state_value: str = None,
    action_prefix: str = None,
    max_records: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified alarms. You can filter the results by specifying a prefix for the alarm name, the alarm state, or a prefix for any action.

    Args:
        alarm_names(List, optional): The names of the alarms to retrieve information about. Defaults to None.
        alarm_name_prefix(str, optional): An alarm name prefix. If you specify this parameter, you receive information about all alarms that have names that start with this prefix. If this parameter is specified, you cannot specify AlarmNames. Defaults to None.
        alarm_types(List, optional): Use this parameter to specify whether you want the operation to return metric alarms or composite alarms. If you omit this parameter, only metric alarms are returned. Defaults to None.
        children_of_alarm_name(str, optional): If you use this parameter and specify the name of a composite alarm, the operation returns information about the "children" alarms of the alarm you specify. These are the metric alarms and composite alarms referenced in the AlarmRule field of the composite alarm that you specify in ChildrenOfAlarmName. Information about the composite alarm that you name in ChildrenOfAlarmName is not returned. If you specify ChildrenOfAlarmName, you cannot specify any other parameters in the request except for MaxRecords and NextToken. If you do so, you receive a validation error.  Only the Alarm Name, ARN, StateValue (OK/ALARM/INSUFFICIENT_DATA), and StateUpdatedTimestamp information are returned by this operation when you use this parameter. To get complete information about these alarms, perform another DescribeAlarms operation and specify the parent alarm names in the AlarmNames parameter. . Defaults to None.
        parents_of_alarm_name(str, optional): If you use this parameter and specify the name of a metric or composite alarm, the operation returns information about the "parent" alarms of the alarm you specify. These are the composite alarms that have AlarmRule parameters that reference the alarm named in ParentsOfAlarmName. Information about the alarm that you specify in ParentsOfAlarmName is not returned. If you specify ParentsOfAlarmName, you cannot specify any other parameters in the request except for MaxRecords and NextToken. If you do so, you receive a validation error.  Only the Alarm Name and ARN are returned by this operation when you use this parameter. To get complete information about these alarms, perform another DescribeAlarms operation and specify the parent alarm names in the AlarmNames parameter. . Defaults to None.
        state_value(str, optional): Specify this parameter to receive information only about alarms that are currently in the state that you specify. Defaults to None.
        action_prefix(str, optional): Use this parameter to filter the results of the operation to only those alarms that use a certain alarm action. For example, you could specify the ARN of an SNS topic to find all alarms that send notifications to that topic. Defaults to None.
        max_records(int, optional): The maximum number of alarm descriptions to retrieve. Defaults to None.
        next_token(str, optional): The token returned by a previous call to indicate that there is more data available. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.alarm.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.alarm.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="describe_alarms",
        op_kwargs={
            "AlarmNames": alarm_names,
            "AlarmNamePrefix": alarm_name_prefix,
            "AlarmTypes": alarm_types,
            "ChildrenOfAlarmName": children_of_alarm_name,
            "ParentsOfAlarmName": parents_of_alarm_name,
            "StateValue": state_value,
            "ActionPrefix": action_prefix,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    launch_configuration_name: str,
    image_id: str = None,
    key_name: str = None,
    security_groups: List = None,
    classic_link_vpc_id: str = None,
    classic_link_vpc_security_groups: List = None,
    user_data: str = None,
    instance_id: str = None,
    instance_type: str = None,
    kernel_id: str = None,
    ramdisk_id: str = None,
    block_device_mappings: List = None,
    instance_monitoring: Dict = None,
    spot_price: str = None,
    iam_instance_profile: str = None,
    ebs_optimized: bool = None,
    associate_public_ip_address: bool = None,
    placement_tenancy: str = None,
    metadata_options: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates a launch configuration. If you exceed your maximum limit of launch configurations, the call fails. To query this limit, call the DescribeAccountLimits API. For information about updating this limit, see Amazon EC2 Auto Scaling service quotas in the Amazon EC2 Auto Scaling User Guide. For more information, see Launch configurations in the Amazon EC2 Auto Scaling User Guide.

    Args:
        launch_configuration_name(str): The name of the launch configuration. This name must be unique per Region per account.
        image_id(str, optional): The ID of the Amazon Machine Image (AMI) that was assigned during registration. For more information, see Finding an AMI in the Amazon EC2 User Guide for Linux Instances. If you do not specify InstanceId, you must specify ImageId. Defaults to None.
        key_name(str, optional): The name of the key pair. For more information, see Amazon EC2 Key Pairs in the Amazon EC2 User Guide for Linux Instances. Defaults to None.
        security_groups(List, optional): A list that contains the security groups to assign to the instances in the Auto Scaling group. [EC2-VPC] Specify the security group IDs. For more information, see Security Groups for Your VPC in the Amazon Virtual Private Cloud User Guide. [EC2-Classic] Specify either the security group names or the security group IDs. For more information, see Amazon EC2 Security Groups in the Amazon EC2 User Guide for Linux Instances. Defaults to None.
        classic_link_vpc_id(str, optional): The ID of a ClassicLink-enabled VPC to link your EC2-Classic instances to. For more information, see ClassicLink in the Amazon EC2 User Guide for Linux Instances and Linking EC2-Classic instances to a VPC in the Amazon EC2 Auto Scaling User Guide. This parameter can only be used if you are launching EC2-Classic instances. Defaults to None.
        classic_link_vpc_security_groups(List, optional): The IDs of one or more security groups for the specified ClassicLink-enabled VPC. For more information, see ClassicLink in the Amazon EC2 User Guide for Linux Instances and Linking EC2-Classic instances to a VPC in the Amazon EC2 Auto Scaling User Guide. If you specify the ClassicLinkVPCId parameter, you must specify this parameter. Defaults to None.
        user_data(str, optional): The user data to make available to the launched EC2 instances. For more information, see Instance metadata and user data (Linux) and Instance metadata and user data (Windows). If you are using a command line tool, base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide base64-encoded text. User data is limited to 16 KB. Defaults to None.
        instance_id(str, optional): The ID of the instance to use to create the launch configuration. The new launch configuration derives attributes from the instance, except for the block device mapping. To create a launch configuration with a block device mapping or override any other instance attributes, specify them as part of the same request. For more information, see Creating a launch configuration using an EC2 instance in the Amazon EC2 Auto Scaling User Guide. If you do not specify InstanceId, you must specify both ImageId and InstanceType. Defaults to None.
        instance_type(str, optional): Specifies the instance type of the EC2 instance. For information about available instance types, see Available Instance Types in the Amazon EC2 User Guide for Linux Instances. If you do not specify InstanceId, you must specify InstanceType. Defaults to None.
        kernel_id(str, optional): The ID of the kernel associated with the AMI. Defaults to None.
        ramdisk_id(str, optional): The ID of the RAM disk to select. Defaults to None.
        block_device_mappings(List, optional): A block device mapping, which specifies the block devices for the instance. You can specify virtual devices and EBS volumes. For more information, see Block Device Mapping in the Amazon EC2 User Guide for Linux Instances. Defaults to None.
        instance_monitoring(Dict, optional): Controls whether instances in this group are launched with detailed (true) or basic (false) monitoring. The default value is true (enabled).  When detailed monitoring is enabled, Amazon CloudWatch generates metrics every minute and your account is charged a fee. When you disable detailed monitoring, CloudWatch generates metrics every 5 minutes. For more information, see Configure Monitoring for Auto Scaling Instances in the Amazon EC2 Auto Scaling User Guide. . Defaults to None.
        spot_price(str, optional): The maximum hourly price to be paid for any Spot Instance launched to fulfill the request. Spot Instances are launched when the price you specify exceeds the current Spot price. For more information, see Requesting Spot Instances in the Amazon EC2 Auto Scaling User Guide.  When you change your maximum price by creating a new launch configuration, running instances will continue to run as long as the maximum price for those running instances is higher than the current Spot price. . Defaults to None.
        iam_instance_profile(str, optional): The name or the Amazon Resource Name (ARN) of the instance profile associated with the IAM role for the instance. The instance profile contains the IAM role. For more information, see IAM role for applications that run on Amazon EC2 instances in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        ebs_optimized(bool, optional): Specifies whether the launch configuration is optimized for EBS I/O (true) or not (false). The optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization is not available with all instance types. Additional fees are incurred when you enable EBS optimization for an instance type that is not EBS-optimized by default. For more information, see Amazon EBS-Optimized Instances in the Amazon EC2 User Guide for Linux Instances. The default value is false. Defaults to None.
        associate_public_ip_address(bool, optional): For Auto Scaling groups that are running in a virtual private cloud (VPC), specifies whether to assign a public IP address to the group's instances. If you specify true, each instance in the Auto Scaling group receives a unique public IP address. For more information, see Launching Auto Scaling instances in a VPC in the Amazon EC2 Auto Scaling User Guide. If you specify this parameter, you must specify at least one subnet for VPCZoneIdentifier when you create your group.  If the instance is launched into a default subnet, the default is to assign a public IP address, unless you disabled the option to assign a public IP address on the subnet. If the instance is launched into a nondefault subnet, the default is not to assign a public IP address, unless you enabled the option to assign a public IP address on the subnet. . Defaults to None.
        placement_tenancy(str, optional): The tenancy of the instance. An instance with dedicated tenancy runs on isolated, single-tenant hardware and can only be launched into a VPC. To launch dedicated instances into a shared tenancy VPC (a VPC with the instance placement tenancy attribute set to default), you must set the value of this parameter to dedicated. If you specify PlacementTenancy, you must specify at least one subnet for VPCZoneIdentifier when you create your group. For more information, see Configuring instance tenancy with Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. Valid Values: default | dedicated . Defaults to None.
        metadata_options(Dict, optional): The metadata options for the instances. For more information, see Configuring the Instance Metadata Options in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.launch_configuration.create(
                ctx, launch_configuration_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.launch_configuration.create launch_configuration_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="create_launch_configuration",
        op_kwargs={
            "LaunchConfigurationName": launch_configuration_name,
            "ImageId": image_id,
            "KeyName": key_name,
            "SecurityGroups": security_groups,
            "ClassicLinkVPCId": classic_link_vpc_id,
            "ClassicLinkVPCSecurityGroups": classic_link_vpc_security_groups,
            "UserData": user_data,
            "InstanceId": instance_id,
            "InstanceType": instance_type,
            "KernelId": kernel_id,
            "RamdiskId": ramdisk_id,
            "BlockDeviceMappings": block_device_mappings,
            "InstanceMonitoring": instance_monitoring,
            "SpotPrice": spot_price,
            "IamInstanceProfile": iam_instance_profile,
            "EbsOptimized": ebs_optimized,
            "AssociatePublicIpAddress": associate_public_ip_address,
            "PlacementTenancy": placement_tenancy,
            "MetadataOptions": metadata_options,
        },
    )


async def delete(hub, ctx, launch_configuration_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified launch configuration. The launch configuration must not be attached to an Auto Scaling group. When this call completes, the launch configuration is no longer available for use.

    Args:
        launch_configuration_name(str): The name of the launch configuration.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.launch_configuration.delete(
                ctx, launch_configuration_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.launch_configuration.delete launch_configuration_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="delete_launch_configuration",
        op_kwargs={"LaunchConfigurationName": launch_configuration_name},
    )


async def describe_all(
    hub,
    ctx,
    launch_configuration_names: List = None,
    next_token: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the launch configurations in the account and Region.

    Args:
        launch_configuration_names(List, optional): The launch configuration names. If you omit this parameter, all launch configurations are described. Array Members: Maximum number of 50 items. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 50 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.launch_configuration.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.launch_configuration.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_launch_configurations",
        op_kwargs={
            "LaunchConfigurationNames": launch_configuration_names,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def phone(hub, ctx, number_validate_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a phone number.

    Args:
        number_validate_request(Dict): Specifies a phone number to validate and retrieve information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.number_validate.phone(
                ctx, number_validate_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.number_validate.phone number_validate_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="phone_number_validate",
        op_kwargs={"NumberValidateRequest": number_validate_request},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, project_arn: str = None, session_id: str = None, session_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    A session is an instance of a browser created through a RemoteWebDriver with the URL from CreateTestGridUrlResult$url. You can use the following to look up sessions:   The session ARN (GetTestGridSessionRequest$sessionArn).   The project ARN and a session ID (GetTestGridSessionRequest$projectArn and GetTestGridSessionRequest$sessionId).

    Args:
        project_arn(str, optional): The ARN for the project that this session belongs to. See CreateTestGridProject and ListTestGridProjects. Defaults to None.
        session_id(str, optional): An ID associated with this session. Defaults to None.
        session_arn(str, optional): An ARN that uniquely identifies a TestGridSession. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.session.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.session.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_test_grid_session",
        op_kwargs={
            "projectArn": project_arn,
            "sessionId": session_id,
            "sessionArn": session_arn,
        },
    )


async def list_all(
    hub,
    ctx,
    project_arn: str,
    status: str = None,
    creation_time_after: str = None,
    creation_time_before: str = None,
    end_time_after: str = None,
    end_time_before: str = None,
    max_result: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of sessions for a TestGridProject.

    Args:
        project_arn(str): ARN of a TestGridProject.
        status(str, optional): Return only sessions in this state. Defaults to None.
        creation_time_after(str, optional): Return only sessions created after this time. Defaults to None.
        creation_time_before(str, optional): Return only sessions created before this time. Defaults to None.
        end_time_after(str, optional): Return only sessions that ended after this time. Defaults to None.
        end_time_before(str, optional): Return only sessions that ended before this time. Defaults to None.
        max_result(int, optional): Return only this many results at a time. Defaults to None.
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.session.init.list_all(
                ctx, project_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.session.init.list_all project_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_test_grid_sessions",
        op_kwargs={
            "projectArn": project_arn,
            "status": status,
            "creationTimeAfter": creation_time_after,
            "creationTimeBefore": creation_time_before,
            "endTimeAfter": end_time_after,
            "endTimeBefore": end_time_before,
            "maxResult": max_result,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    monitoring_schedule_name: str = None,
    endpoint_name: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
    scheduled_time_before: str = None,
    scheduled_time_after: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
    last_modified_time_before: str = None,
    last_modified_time_after: str = None,
    status_equals: str = None,
    monitoring_job_definition_name: str = None,
    monitoring_type_equals: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns list of all monitoring job executions.

    Args:
        monitoring_schedule_name(str, optional): Name of a specific schedule to fetch jobs for. Defaults to None.
        endpoint_name(str, optional): Name of a specific endpoint to fetch jobs for. Defaults to None.
        sort_by(str, optional): Whether to sort results by Status, CreationTime, ScheduledTime field. The default is CreationTime. Defaults to None.
        sort_order(str, optional): Whether to sort the results in Ascending or Descending order. The default is Descending. Defaults to None.
        next_token(str, optional): The token returned if the response is truncated. To retrieve the next set of job executions, use it in the next request. Defaults to None.
        max_results(int, optional): The maximum number of jobs to return in the response. The default value is 10. Defaults to None.
        scheduled_time_before(str, optional): Filter for jobs scheduled before a specified time. Defaults to None.
        scheduled_time_after(str, optional): Filter for jobs scheduled after a specified time. Defaults to None.
        creation_time_before(str, optional): A filter that returns only jobs created before a specified time. Defaults to None.
        creation_time_after(str, optional): A filter that returns only jobs created after a specified time. Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only jobs modified after a specified time. Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only jobs modified before a specified time. Defaults to None.
        status_equals(str, optional): A filter that retrieves only jobs with a specific status. Defaults to None.
        monitoring_job_definition_name(str, optional): Gets a list of the monitoring job runs of the specified monitoring job definitions. Defaults to None.
        monitoring_type_equals(str, optional): A filter that returns only the monitoring job runs of the specified monitoring type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.monitoring.execution.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.monitoring.execution.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_monitoring_executions",
        op_kwargs={
            "MonitoringScheduleName": monitoring_schedule_name,
            "EndpointName": endpoint_name,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
            "ScheduledTimeBefore": scheduled_time_before,
            "ScheduledTimeAfter": scheduled_time_after,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "StatusEquals": status_equals,
            "MonitoringJobDefinitionName": monitoring_job_definition_name,
            "MonitoringTypeEquals": monitoring_type_equals,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, resources: List, tags: List, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Adds or overwrites only the specified tags for the specified Amazon EC2 resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value. Tag keys must be unique per resource. For more information about tags, see Tagging Your Resources in the Amazon Elastic Compute Cloud User Guide. For more information about creating IAM policies that control users' access to resources based on tags, see Supported Resource-Level Permissions for Amazon EC2 API Actions in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        resources(List): The IDs of the resources, separated by spaces. Constraints: Up to 1000 resource IDs. We recommend breaking up this request into smaller batches.
        tags(List): The tags. The value parameter is required, but if you don't want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.tags.create(ctx, resources=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.tags.create resources=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_tags",
        op_kwargs={"DryRun": dry_run, "Resources": resources, "Tags": tags},
    )


async def delete(
    hub, ctx, resources: List, dry_run: bool = None, tags: List = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified set of tags from the specified set of resources. To list the current tags, use DescribeTags. For more information about tags, see Tagging Your Resources in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        resources(List): The IDs of the resources, separated by spaces. Constraints: Up to 1000 resource IDs. We recommend breaking up this request into smaller batches.
        tags(List, optional): The tags to delete. Specify a tag key and an optional tag value to delete specific tags. If you specify a tag key without a tag value, we delete any tag with this key regardless of its value. If you specify a tag key with an empty string as the tag value, we delete the tag only if its value is an empty string. If you omit this parameter, we delete all user-defined tags for the specified resources. We do not delete Amazon Web Services-generated tags (tags that have the aws: prefix). Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.tags.delete(ctx, resources=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.tags.delete resources=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_tags",
        op_kwargs={"DryRun": dry_run, "Resources": resources, "Tags": tags},
    )


async def describe(
    hub,
    ctx,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified tags for your EC2 resources. For more information about tags, see Tagging Your Resources in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): The filters.    key - The tag key.    resource-id - The ID of the resource.    resource-type - The resource type (customer-gateway | dedicated-host | dhcp-options | elastic-ip | fleet | fpga-image | host-reservation | image | instance | internet-gateway | key-pair | launch-template | natgateway | network-acl | network-interface | placement-group | reserved-instances | route-table | security-group | snapshot | spot-instances-request | subnet | volume | vpc | vpc-endpoint | vpc-endpoint-service | vpc-peering-connection | vpn-connection | vpn-gateway).    tag:<key> - The key/value combination of the tag. For example, specify "tag:Owner" for the filter name and "TeamA" for the filter value to find resources with the tag "Owner=TeamA".    value - The tag value.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. This value can be between 5 and 1000. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.tags.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.tags.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_tags",
        op_kwargs={
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )
